@@ -27,7 +27,7 @@ from PyQt4.QtCore import *
 from PyQt4.QtGui import *
 
 app_name = "ReText"
-app_version = "3.1.0"
+app_version = "3.1.3"
 
 def readFromSettings(settings, key, keytype):
 	try:
@@ -544,7 +544,7 @@ class ReTextWindow(QMainWindow):
 		if settings.contains('previewState'):
 			self.livePreviewEnabled = readFromSettings(settings, 'previewState', bool)
 		self.ind = 0
-		self.tabWidget.addTab(self.createTab(""), self.tr('New document'))
+		self.tabWidget.addTab(self.createTab(), self.tr('New document'))
 		self.highlighters[0].docType = self.getDocType()
 		if use_enchant:
 			self.sl = None
@@ -594,7 +594,7 @@ class ReTextWindow(QMainWindow):
 		splitter.setChildrenCollapsible(False)
 		return splitter
 	
-	def createTab(self, fileName):
+	def createTab(self):
 		self.previewBlocked = False
 		self.editBoxes.append(QTextEdit())
 		self.highlighters.append(ReTextHighlighter(self.editBoxes[-1].document()))
@@ -609,7 +609,7 @@ class ReTextWindow(QMainWindow):
 			self.previewBoxes[-1].setReadOnly(True)
 		self.editBoxes[-1].contextMenuEvent = self.editBoxMenuEvent
 		self.previewBoxes[-1].setVisible(False)
-		self.fileNames.append(fileName)
+		self.fileNames.append("")
 		liveMode = self.restorePreviewState and self.livePreviewEnabled
 		self.apc.append(liveMode)
 		self.alpc.append(liveMode)
@@ -641,11 +641,11 @@ class ReTextWindow(QMainWindow):
 			# For Python 2
 			curchar = text.at(pos)
 			isalpha = curchar.isLetter()
-		if not isalpha:
-			return QTextEdit.contextMenuEvent(editBox, event)
 		cursor.select(QTextCursor.WordUnderCursor)
+		if not isalpha or (oldcursor.hasSelection() and
+		oldcursor.selectedText() != cursor.selectedText()):
+			return QTextEdit.contextMenuEvent(editBox, event)
 		editBox.setTextCursor(cursor)
-		word = cursor.selectedText()
 		try:
 			word = unicode(cursor.selectedText())
 		except NameError:
@@ -668,7 +668,7 @@ class ReTextWindow(QMainWindow):
 	def closeTab(self, ind):
 		if self.maybeSave(ind):
 			if self.tabWidget.count() == 1:
-				self.tabWidget.addTab(self.createTab(""), self.tr("New document"))
+				self.tabWidget.addTab(self.createTab(), self.tr("New document"))
 			del self.editBoxes[ind]
 			del self.previewBoxes[ind]
 			del self.highlighters[ind]
@@ -862,6 +862,12 @@ class ReTextWindow(QMainWindow):
 		self.previewBlocked = False
 		pb = self.previewBoxes[self.ind]
 		textedit = isinstance(pb, QTextEdit)
+		if textedit:
+			scrollbar = pb.verticalScrollBar()
+			scrollpos = scrollbar.value()
+		else:
+			frame = pb.page().mainFrame()
+			scrollpos = frame.scrollPosition()
 		if self.ss and textedit:
 			pb.document().setDefaultStyleSheet(self.ss)
 		if self.getDocType() == DOCTYPE_PLAINTEXT:
@@ -887,6 +893,10 @@ class ReTextWindow(QMainWindow):
 					parsedText + '</body></html>\n')
 		if self.font and textedit:
 			pb.document().setDefaultFont(self.font)
+		if textedit:
+			scrollbar.setValue(scrollpos)
+		else:
+			frame.setScrollPosition(scrollpos)
 	
 	def updateLivePreviewBox(self):
 		if self.actionLivePreview.isChecked() and self.previewBlocked == False:
@@ -935,7 +945,7 @@ class ReTextWindow(QMainWindow):
 		self.docTypeChanged()
 	
 	def createNew(self):
-		self.tabWidget.addTab(self.createTab(""), self.tr("New document"))
+		self.tabWidget.addTab(self.createTab(), self.tr("New document"))
 		self.ind = self.tabWidget.count()-1
 		self.tabWidget.setCurrentIndex(self.ind)
 	
@@ -1048,7 +1058,7 @@ class ReTextWindow(QMainWindow):
 		elif QFile.exists(fileName):
 			if self.fileNames[self.ind] or self.editBoxes[self.ind].toPlainText() \
 			or self.editBoxes[self.ind].document().isModified():
-				self.tabWidget.addTab(self.createTab(""), "")
+				self.tabWidget.addTab(self.createTab(), "")
 				self.ind = self.tabWidget.count()-1
 				self.tabWidget.setCurrentIndex(self.ind)
 			self.fileNames[self.ind] = fileName
@@ -1098,9 +1108,11 @@ class ReTextWindow(QMainWindow):
 				ext = ".mkd"
 				if settings.contains('defaultExt'):
 					ext = readFromSettings(settings, 'defaultExt', str)
-			self.fileNames[self.ind] = QFileDialog.getSaveFileName(self, self.tr("Save file"), "", defaultExt)
-			if self.fileNames[self.ind] and not QFileInfo(self.fileNames[self.ind]).suffix():
-				self.fileNames[self.ind] += ext
+			newFileName = QFileDialog.getSaveFileName(self, self.tr("Save file"), "", defaultExt)
+			if newFileName:
+				if not QFileInfo(newFileName).suffix():
+					newFileName += ext
+				self.fileNames[self.ind] = newFileName
 		if self.fileNames[self.ind]:
 			result = self.saveFileCore(self.fileNames[self.ind])
 			if result:
@@ -1182,7 +1194,6 @@ class ReTextWindow(QMainWindow):
 			return self.textDocument()
 		except Exception as e:
 			self.printError(e)
-			return None
 	
 	def standardPrinter(self):
 		printer = QPrinter(QPrinter.HighResolution)
@@ -1242,9 +1253,8 @@ class ReTextWindow(QMainWindow):
 			self.saveFileCore(tmpname)
 		command = command.replace('%of', 'out'+defaultext)
 		command = command.replace('%html' if html else '%if', tmpname)
-		args = str(command).split()
 		try:
-			Popen(args).wait()
+			Popen(str(command), shell=True).wait()
 		except Exception as error:
 			errorstr = str(error)
 			try:
@@ -1470,19 +1480,19 @@ class ReTextWindow(QMainWindow):
 	
 	def parseText(self):
 		try:
-			htmltext = unicode(self.editBoxes[self.ind].toPlainText())
+			text = unicode(self.editBoxes[self.ind].toPlainText())
 		except:
 			# For Python 3
-			htmltext = self.editBoxes[self.ind].toPlainText()
+			text = self.editBoxes[self.ind].toPlainText()
 		# WpGen directives
-		htmltext = htmltext.replace('%HTMLDIR%', 'html')
-		htmltext = htmltext.replace('%\\', '%')
+		text = text.replace('%HTMLDIR%', 'html')
+		text = text.replace('%\\HTMLDIR%', '%HTMLDIR%')
 		parser = self.getParser()
 		if parser == PARSER_DOCUTILS:
-			return publish_parts(htmltext, writer_name='html')['body']
+			return publish_parts(text, writer_name='html')['body']
 		elif parser == PARSER_MARKDOWN:
 			md.reset()
-			return md.convert(htmltext)
+			return md.convert(text)
 		else:
 			return '<p style="color: red">'\
 			+self.tr('Could not parse file contents, check if you have the necessary module installed!')+'</p>'
@@ -1506,6 +1516,7 @@ def main(fileNames):
 		app.setStyleSheet(QTextStream(sheetfile).readAll())
 		sheetfile.close()
 	window = ReTextWindow()
+	window.show()
 	for fileName in fileNames:
 		try:
 			fileName = QString.fromUtf8(fileName)
@@ -1514,7 +1525,6 @@ def main(fileNames):
 			pass
 		if QFile.exists(fileName):
 			window.openFileWrapper(fileName)
-	window.show()
 	sys.exit(app.exec_())
 
 if __name__ == '__main__':
